pyhsm.defines

Package pyhsm :: Module defines |
[frames] | no frames]

# Module defines

Various defines from pyhsm_if.h.

Functions
status2str(num) Return YubiHSM response status code as string. |
cmd2str(cmd) Return command as string. |

Variables
| YSM_PUBLIC_ID_SIZE = `6`
| YSM_OTP_SIZE = `16`
| YSM_BLOCK_SIZE = `16`
| YSM_MAX_KEY_SIZE = `32`
| YSM_DATA_BUF_SIZE = `64`
| YSM_AEAD_NONCE_SIZE = `6`
| YSM_AEAD_MAC_SIZE = `8`
| YSM_CCM_CTR_SIZE = `2`
| YSM_AEAD_MAX_SIZE = `72`
| YSM_SHA1_HASH_SIZE = `20`
| YSM_CTR_DRBG_SEED_SIZE = `32`
| YSM_MAX_PKT_SIZE = `96`
| YSM_PROTOCOL_VERSION = `1`
| YSM_TEMP_KEY_HANDLE = `4294967295`
| UID_SIZE = `6`
| KEY_SIZE = `16`
| YSM_STATUS_OK = `128`
| YSM_KEY_HANDLE_INVALID = `129`
| YSM_AEAD_INVALID = `130`
| YSM_OTP_INVALID = `131`
| YSM_OTP_REPLAY = `132`
| YSM_ID_DUPLICATE = `133`
| YSM_ID_NOT_FOUND = `134`
| YSM_DB_FULL = `135`
| YSM_MEMORY_ERROR = `136`
| YSM_FUNCTION_DISABLED = `137`
| YSM_KEY_STORAGE_LOCKED = `138`
| YSM_MISMATCH = `139`
| YSM_INVALID_PARAMETER = `140`
| YSM_NULL = `0`
| YSM_AEAD_GENERATE = `1`
| YSM_BUFFER_AEAD_GENERATE = `2`
| YSM_RANDOM_AEAD_GENERATE = `3`
| YSM_AEAD_DECRYPT_CMP = `4`
| YSM_DB_YUBIKEY_AEAD_STORE = `5`
| YSM_AEAD_YUBIKEY_OTP_DECODE = `6`
| YSM_DB_OTP_VALIDATE = `7`
| YSM_DB_YUBIKEY_AEAD_STORE2 = `8`
| YSM_AES_ECB_BLOCK_ENCRYPT = `13`
| YSM_AES_ECB_BLOCK_DECRYPT = `14`
| YSM_AES_ECB_BLOCK_DECRYPT_CMP = `15`
| YSM_HMAC_SHA1_GENERATE = `16`
| YSM_TEMP_KEY_LOAD = `17`
| YSM_BUFFER_LOAD = `32`
| YSM_BUFFER_RANDOM_LOAD = `33`
| YSM_NONCE_GET = `34`
| YSM_ECHO = `35`
| YSM_RANDOM_GENERATE = `36`
| YSM_RANDOM_RESEED = `37`
| YSM_SYSTEM_INFO_QUERY = `38`
| YSM_MONITOR_EXIT = `127`